## Summary
[What this PR does in 1-2 sentences]

## ADRs
- [ ] ADR-NNN: [title] (if architectural decisions were made)
- [ ] No architectural decisions in this PR

## Compliance Checklist
- [ ] Tests pass (`make test`)
- [ ] Coverage >=90%
- [ ] Lint clean (`make lint`)
- [ ] No secrets in code
- [ ] ADRs committed before code (if applicable)
- [ ] Commit messages follow conventional format

## Closes
Closes #[issue number]
